NiGSP
=====

[![Latest version](https://img.shields.io/github/v/release/MIPLabCH/nigsp?style=flat&logo=github&sort=semver)](https://github.com/MIPLabCH/nigsp/releases)
[![Release date](https://img.shields.io/github/release-date/MIPLabCH/nigsp?style=flat&logo=github)](https://github.com/MIPLabCH/nigsp/releases)
[![Auto Release](https://img.shields.io/badge/release-auto.svg?style=flat&colorA=888888&colorB=9B065A&label=auto&logo=data:image/png;base64, )](https://github.com/intuit/auto)

[![See the documentation at: https://nigsp.readthedocs.io](https://img.shields.io/badge/docs-read%20latest-informational?style=flat&logo=readthedocs)](https://nigsp.readthedocs.io/en/latest/?badge=latest)
[![Latest DOI](https://zenodo.org/badge/446805866.svg?style=flat&logo=zenodo)](https://zenodo.org/badge/latestdoi/446805866)
[![Licensed Apache 2.0](https://img.shields.io/github/license/MIPLabCH/nigsp?style=flat&logo=apache)](https://github.com/MIPLabCH/nigsp/blob/master/LICENSE)

[![Codecov](https://img.shields.io/codecov/c/gh/MIPlabCH/nigsp?style=flat&label=codecov&logo=codecov)](https://codecov.io/gh/MIPLabCH/nigsp)
[![Build Status](https://img.shields.io/circleci/build/github/MIPLabCH/nigsp?style=flat&label=circleci&logo=circleci)](https://circleci.com/gh/MIPLabCH/nigsp)
[![Documentation Status](https://img.shields.io/readthedocs/nigsp?style=flat&label=readthedocs&logo=readthedocs)](https://nigsp.readthedocs.io/en/latest/?badge=latest)

[![Latest version](https://img.shields.io/pypi/v/nigsp?style=flat&logo=pypi&logoColor=white)](https://pypi.org/project/nigsp/)
[![Supports python version](https://img.shields.io/pypi/pyversions/nigsp?style=flat&logo=python&logoColor=white)](https://pypi.org/project/nigsp/)

<!-- ALL-CONTRIBUTORS-BADGE:START - Do not remove or modify this section -->
[![All Contributors](https://img.shields.io/badge/all_contributors-1-orange.svg?style=flat)](#contributors)
<!-- ALL-CONTRIBUTORS-BADGE:END -->


A python library (and toolbox!) to run Graph Signal Processing on multimodal MRI data.
Full documentation [on ReadTheDocs](https://nigsp.readthedocs.io/en/latest)

**The project is currently under development stage alpha**.
Any suggestion/bug report is welcome! Feel free to open an issue.

This project follows the [all-contributors](https://github.com/all-contributors/all-contributors) specification. Contributions of any kind welcome!

Cite
====

If you use `nigsp` in your work, **please cite either the all-time Zenodo DOI** [![general Zenodo DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.6373436.svg)](https://zenodo.org/badge/latestdoi/446805866) **or the Zenodo DOI related to the version you are using**.
Please cite the following paper(s) too:
> Preti, M.G., Van De Ville, D. _Decoupling of brain function from structure reveals regional behavioral specialization in humans_. Nat Commun 10, 4747 (2019). https://doi.org/10.1038/s41467-019-12765-7.

If you are using the Couple/Decoupled Functional Connectivity, please cite also:
> Griffa, A., et al. _Brain structure-function coupling provides signatures for task decoding and individual fingerprinting_. NeuroImage 250, 118970 (2022). https://doi.org/10.1016/j.neuroimage.2022.118970.

<!-- ## Contributors ✨

Thanks goes to these wonderful people ([emoji key](https://allcontributors.org/docs/en/emoji-key)): -->

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->


<!-- markdownlint-enable -->
<!-- prettier-ignore-end -->
<!-- ALL-CONTRIBUTORS-LIST:END -->


License
-------

Copyright 2022, Stefano Moia, EPFL.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
